@@ -20,13 +20,17 @@
 require 'aprs4r/PluginConfiguration'
 
 
-class QueryPluginConfiguration < PluginConfiguration
+module APRS4R
 
-  attr_reader :device, :call
-  attr_writer :device, :call
+  class QueryPluginConfiguration < PluginConfiguration
+
+    attr_reader :device, :call
+    attr_writer :device, :call
+
+    def to_yaml_properties
+      return super + %w{@device @call}
+    end
 
-  def to_yaml_properties
-    return super + %w{@device @call}
   end
 
 end
